
import { Image, Text, Textarea, View } from "@tarojs/components"
import Taro, { useDidShow, usePullDownRefresh, useRouter } from "@tarojs/taro";
import { useCallback, useEffect, useMemo, useRef, useState } from "react";
import { useBluetooth } from "@/use/contextBlueTooth"
import classnames from "classnames";
import LinkBlueTooth from "./compoents/bluetooth/LinkBlueTooth";
import { toRgb } from '@/common/bluetooth/color/colorSpace'
import styles from './index.module.scss'

export default () => {
    //搜索参数
    const [searchField, setSearchField] = useState({
        l: '',
        a: '',
        b: '',
        page: 1,
        size: 10,
        width: '',
        weight_density: '',
        product_kind_id: '',
        component: ''
    })
    const { state: colorState, measureAndGetLab } = useBluetooth()
    const getLab = () => {
        if (colorState.connected) {
            measureAndGetLab()
        } else {
            Taro.showToast({
                title: '请链接设备',
                icon: 'none'
            })
        }
    }
    //监听lab数据变化
    const [blueToothColor, setBlueToothColor] = useState('')
    useEffect(() => {
        if (colorState.deviceLab) {
            const rgb = toRgb([colorState.deviceLab.L, colorState.deviceLab.a, colorState.deviceLab.b])
            setBlueToothColor(`rgb(${rgb[0]}, ${rgb[1]}, ${rgb[2]})`)
            setSearchField({ ...searchField, l: rgb[0], a: rgb[1], b: rgb[2], size: 10 })
        }
    }, [colorState.deviceLab])
    return (
        <View className={styles.body}>
            {/* <View className={styles.topBox}>
                <View className={styles.leftBox}>
                    <View className={styles.leftFont}>蓝牙设备</View>
                    <View className={styles.borderBox}></View>
                    <View className={styles.cricleBox}></View>
                    <View className={styles.notNet}></View>
                </View>
                <Text className={classnames("iconfont icon-a-moreback", styles.iconMore)}></Text>
            </View> */}
            <LinkBlueTooth />
            <View className={styles.contBox} >
                <View className={styles.firstBox} style="margin-right:27px">
                    <View className={styles.firstLeftName} >对比样品</View>
                    {
                        blueToothColor === '' &&
                        <View className={styles.firstLeftbox} onClick={() => getLab()}>
                            <View className={styles.clickFont} >点击取色</View>
                        </View>
                    }
                    {blueToothColor && <View className={classnames(styles.color_bock)} style={{ background: blueToothColor }}></View>

                    }
                    <View className={styles.nameColor}>--</View>
                </View>
                <View className={styles.firstBox}>
                    <View className={styles.firstLeftName}>对比样品</View>
                    <View className={styles.firstLeftbox}>
                        <View className={styles.clickFont} onClick={() => getLab()}>点击取色</View>
                    </View>
                    <View className={styles.nameColor}>--</View>
                </View>
            </View>
            <View className={styles.reslutBox}>
                <View className={styles.reslutTitle}>
                    <View className={styles.titleLeft}>测量结果</View>
                    {/* <View className={styles.titleRiht}>不合格</View> */}
                    <View className={styles.titleRiht1}>合格</View>
                </View>
                {/* <View className={styles.notResult}>暂无数据</View> */}
                <View className={styles.notBox}>
                    <View className={styles.notLeft}>色差值: 0.2</View>
                    <View className={styles.notright}>无明显色差</View>
                </View>
            </View>
        </View>
    )
}